package com.ruoyi.aicall.service;

import java.util.List;
import com.ruoyi.aicall.domain.CcLlmKb;
import io.swagger.models.auth.In;
import org.springframework.web.multipart.MultipartFile;

/**
 * 知识库内容Service接口
 * 
 * @author ruoyi
 * @date 2026-01-19
 */
public interface ICcLlmKbService 
{
    /**
     * 查询知识库内容
     * 
     * @param id 知识库内容主键
     * @return 知识库内容
     */
    public CcLlmKb selectCcLlmKbById(Long id);

    /**
     * 查询知识库内容列表
     * 
     * @param ccLlmKb 知识库内容
     * @return 知识库内容集合
     */
    public List<CcLlmKb> selectCcLlmKbList(CcLlmKb ccLlmKb);

    /**
     * 新增知识库内容
     * 
     * @param ccLlmKb 知识库内容
     * @return 结果
     */
    public int insertCcLlmKb(CcLlmKb ccLlmKb);

    /**
     * 修改知识库内容
     * 
     * @param ccLlmKb 知识库内容
     * @return 结果
     */
    public int updateCcLlmKb(CcLlmKb ccLlmKb);

    /**
     * 批量删除知识库内容
     * 
     * @param ids 需要删除的知识库内容主键集合
     * @return 结果
     */
    public int deleteCcLlmKbByIds(String ids);

    /**
     * 删除知识库内容信息
     * 
     * @param id 知识库内容主键
     * @return 结果
     */
    public int deleteCcLlmKbById(Long id);

    Integer selectCountByCatId(Long catId);

    String importData(MultipartFile file,  Long fixedCatId) throws Exception;

    CcLlmKb selectCcLlmKbContentByTitle(Long id, String title, Long catId);
    
}
